import pytest
import typing
from io import BytesIO
from base64 import b64decode
from charset_normalizer import is_binary
from os import path, pardir

DIR_PATH = path.join(
    path.dirname(path.realpath(__file__)),
    pardir
)


@pytest.mark.parametrize(
    "raw, expected",
    [
        (b'\x00\x5f\x2f\xff'*50, True),
        (b64decode("R0lGODlhAQABAAAAACw="), True),
        (BytesIO(b64decode("R0lGODlhAQABAAAAACw=")), True),
        ('sample-polish.txt', False),
        ('sample-arabic.txt', False)
    ]
)
def test_isbinary(raw: typing.Union[bytes, typing.BinaryIO, str], expected: bool) -> None:
    if isinstance(raw, str):
        raw = DIR_PATH + "/data/{}".format(raw)

    assert is_binary(raw) is expected



from charset_normalizer import from_bytes
import pytest
import platform

@pytest.mark.xfail(platform.python_version_tuple()[0] == "3" and platform.python_version_tuple()[1] == "7", reason="Unicode database is too old for this case (Python 3.7)")
def test_unicode_edge_case():
    payload = b'\xef\xbb\xbf\xf0\x9f\xa9\xb3'

    best_guess = from_bytes(payload).best()

    assert best_guess is not None, "Payload should have given something, detection failure"
    assert best_guess.encoding == "utf_8", "UTF-8 payload wrongly detected"
